<?php
/*
Plugin Name: CSS3 Tooltips For WordPress
Plugin URI: http://codecanyon.net/item/css3-tooltips-for-wordpress/7416713?ref=QuanticaLabs
Description: CSS3 Tooltips For WordPress is a lightweight, easy-to-use tooltips plugin for WordPress. It's based on pure CSS3 and comes loaded with 50 predefined CSS3 styles, 10 different tooltip positions, optional tooltip headers, support for images and videos, adjustable delay, notification icons, tooltips On Hover over element and On Click and support for mobile devices. Plugin comes with shortcode generator and global settings with nice feature to display CSS3 Tooltips for all links by default.
Author: QuanticaLabs
Author URI: http://themeforest.net/user/QuanticaLabs?ref=QuanticaLabs
Version: 1.4
*/

// BASIC CONSTANTS
define("CSS3_TOOLTIPS_PLUGIN_PATH", plugin_dir_path(__FILE__));
define("CSS3_TOOLTIPS_PLUGIN_URL", plugin_dir_url(__FILE__));
define("CSS3_TOOLTIPS_CSS_URL", CSS3_TOOLTIPS_PLUGIN_URL . "styles/");
define("CSS3_TOOLTIPS_CSS_PATH", CSS3_TOOLTIPS_PLUGIN_PATH . "styles/");
define("CSS3_TOOLTIPS_JS_URL", CSS3_TOOLTIPS_PLUGIN_URL . "js/");
define("CSS3_TOOLTIPS_JS_PATH", CSS3_TOOLTIPS_PLUGIN_PATH . "js/");
define("CSS3_TOOLTIPS_IMAGES_URL", CSS3_TOOLTIPS_PLUGIN_URL . "images/");
define("CSS3_TOOLTIPS_IMAGES_PATH", CSS3_TOOLTIPS_PLUGIN_PATH . "images/");

/**
 * Main plugin class
 */
class CCS3_Tooltips {
	
	/**
	 * Stores default values of shortcode parameters
	 * @var mixed 
	 */
	private $default_options;

	/**
	 * Class constructor
	 */
	public function __construct() {
		global $css3_tooltips_js;
		
		$css3_tooltips_js = false;
		$this->css3_tooltips_setup();
		$this->default_options = self::css3_tooltips_default_options();
		
		wp_enqueue_script("jquery");
		wp_enqueue_style("css3_tooltips_main", CSS3_TOOLTIPS_CSS_URL . "tooltips_main.css", false, filemtime(CSS3_TOOLTIPS_CSS_PATH . "tooltips_main.css"));
		wp_enqueue_style("css3_tooltips_styles", CSS3_TOOLTIPS_CSS_URL . "tooltips_styles.css", false, filemtime(CSS3_TOOLTIPS_CSS_PATH . "tooltips_styles.css"));
		
		add_shortcode("css3_tooltip", array($this, "css3_tooltips_shortcode"));
		add_action("init", array($this, "init_buttons"));
		add_action("admin_menu", array($this, "css3_tooltips_menu"));
		add_action("wp_ajax_settings_save", array($this, "css3_tooltips_settings_save"));
		add_action("wp_footer", array($this, "css3_tooltips_footer")); 
		add_filter("the_content", array($this, "css3_tooltips_links_to_tooltips"));
		add_filter("the_content", array($this, "css3_tooltips_text_to_tooltips"));
	}

	/**
	 * Function adds necessary options just after plugin installation
	 */
	public function css3_tooltips_setup() {
		if (!get_option("css3_tooltips_installed")) {
			// Define default tooltips settings
			add_option("css3_tooltips_custom_css_class", "");
			add_option("css3_tooltips_width", "180px");
			add_option("css3_tooltips_tag", "a");
			add_option("css3_tooltips_style", "1");
			add_option("css3_tooltips_custom_css", "");
			add_option("css3_tooltips_custom_content_css", "");
			add_option("css3_tooltips_position", "top");
			add_option("css3_tooltips_delay", "0");
			add_option("css3_tooltips_cursor", "pointer");
			add_option("css3_tooltips_event", "hover");
			add_option("css3_tooltips_links_to_tooltips", "");
			add_option("css3_tooltips_text_to_tooltips", "");
			add_option("css3_tooltips_text_to_tooltips_text", "");
			add_option("css3_tooltips_text_to_tooltips_content", "");
			add_option("css3_tooltips_installed", "1");
		}
	}

	/**
	 * Loads default shortcode options into $options variable
	 */
	public static function css3_tooltips_default_options() {
		$default_options = array(
			"position" => get_option("css3_tooltips_position"),
			"style" => get_option("css3_tooltips_style"),
			"custom_css" => str_replace("'","\"", stripslashes(get_option("css3_tooltips_custom_css"))),
			"custom_css_class" => get_option("css3_tooltips_custom_css_class"),
			"custom_content_css" => str_replace("'","\"", stripslashes(get_option("css3_tooltips_custom_content_css")) ),
			"delay" => get_option("css3_tooltips_delay"),
			"links_to_tooltips" => get_option("css3_tooltips_links_to_tooltips"),
			"text_to_tooltips" => get_option("css3_tooltips_text_to_tooltips"),
			"text_to_tooltips_text" => str_replace("'","\"", stripslashes(get_option("css3_tooltips_text_to_tooltips_text"))),
			"text_to_tooltips_content" => str_replace("'","\"", stripslashes(get_option("css3_tooltips_text_to_tooltips_content"))),
			"width" => get_option("css3_tooltips_width"),
			"tag" => get_option("css3_tooltips_tag"),			
			"cursor" => get_option("css3_tooltips_cursor"),
			"event" => get_option("css3_tooltips_event")
		);
		return $default_options;
	}
	
	/**
	 * Prepares a set of predefined values for shortcode options
	 */
	public static function css3_tooltips_predefined_values() {
		$predefined_values = array(
			"position" => array(
				"top" => __("Top", "css3_tooltips"),
				"top_center" => __("Top center", "css3_tooltips"),
				"diagonal_right_top" => __("Diagonal right top", "css3_tooltips"),
				"right" => __("Right", "css3_tooltips"),
				"diagonal_right_bottom" => __("Diagonal right bottom", "css3_tooltips"),
				"bottom" => __("Bottom", "css3_tooltips"),
				"bottom_center" => __("Bottom center", "css3_tooltips"),
				"diagonal_left_bottom" => __("Diagonal left center", "css3_tooltips"),
				"left" => __("Left", "css3_tooltips"),
				"diagonal_left_top" => __("Diagonal left top", "css3_tooltips")
			),
			"style" => range(1, 50),
			"tag" => array(
				"a" => "&lt;a&gt;",
				"b" => "&lt;b&gt;",
				"em" => "&lt;em&gt;",
				"strong" => "&lt;strong&gt;",
				"i" => "&lt;i&gt;",
				"span" => "&lt;span&gt;",
				"p" => "&lt;p&gt;",
				"h1" => "&lt;h1&gt;",
				"h2" => "&lt;h2&gt;",
				"h3" => "&lt;h3&gt;",
				"h4" => "&lt;h4&gt;",
				"h5" => "&lt;h5&gt;",
				"h6" => "&lt;h6&gt;",
				"label" => "&lt;label&gt;",
				"blockquote" => "&lt;blockquote&gt;",
				"custom_tag" => __("Custom Tag", "css3_tooltips"),
			),
			"delay" => array("0", "100", "200", "300", "500", "700"),
			"cursor" => array(
				"default" => __("Default", "css3_tooltips"),
				"pointer" => __("Pointer", "css3_tooltips"),
				"help" => __("Help", "css3_tooltips")
			),
			"event" => array(
				"hover" => __("Hover", "css3_tooltips"),
				"click" => __("Click", "css3_tooltips")
			),
			"video_size" => array(
				"240,152" => "240 x 152",
				"560,315" => "560 x 315",
				"640,360" => "640 x 360",
				"853,480" => "853 x 480",
				"1280,720" => "1280 x 720",
				"custom_size" => __("Custom Size", "css3_tooltips")
			)
		);
		return $predefined_values;
	}
	
	
	/**
	 * Method handles tooltip shortcode 
	 * @param mixed $atts
	 * @param string $text
	 * @return string
	 */
	public function css3_tooltips_shortcode($atts, $text) {
		
		extract(shortcode_atts(array(
			"header" =>				"",
			"content" =>			"Tooltip Content",
			"style" =>				$this->default_options["style"],
			"position" =>			$this->default_options["position"],
			"width" =>				"",
			"custom_css_class" =>	"",
			"custom_css" =>			"",
			"custom_content_css" => "",
			"focus" =>				"",
			"tag" =>				$this->default_options["tag"],
			"delay" =>				"",
			"cursor" =>				"",
			"event" =>				"",
			"attr" =>				""
			),
			$atts
		));
		
		// Prepare atributes:
		if ($focus == 1) {
			$parts = explode("_", $position);
			array_splice($parts, 1, 0, "focus");
			$position = implode("_", $parts);
		}
		$position = "qlabs_tooltip_" . $position;
		$delay = $delay != "" && $delay != 0 ? " delay_" . $delay : "";
		$style = " qlabs_tooltip_" . $style;
		$cursor = $cursor != "" ? " cursor_" . $cursor : "";
		$event = $event != "" ? " event_" . $event : "";
		$custom_css_class = $custom_css_class != "" ? " " . $custom_css_class : "";
		$custom_content_css = $custom_content_css != "" ? " " . $custom_content_css : "";
		
		// Generate output
		$output = "<{$tag} class='{$position}{$style}{$delay}{$cursor}{$custom_css_class}{$event}' style='{$custom_css}' {$attr} aria-haspopup='true'>";
		$output .= $text;
		$output .= "<span " . ($width != "" ? "style='width: {$width}; {$custom_content_css}' " : "") . " >";
		$output .= $header != "" ? "<strong>{$header}</strong>" : "";
		$output .= $content;
		$output .= "</span>";
		$output .= "</{$tag}>";

		// Check if click event is selected, required for loading JS code
		if( strpos($event, 'click')!==false  ) {
			global $css3_tooltips_js;
			$css3_tooltips_js = true;
		} 
		
		return $output;
	}

	/**
	 * Filter function which will convert links to tooltips
	 * @param type $content content of the post/page
	 * @return type
	 */
	function css3_tooltips_links_to_tooltips($content) {
		// convert links into tooltips only if it was set in global settings
		if(get_option("css3_tooltips_links_to_tooltips") == 1) {
		
			// Get default options
			$default_options = CCS3_Tooltips::css3_tooltips_default_options();
			
			// REPLACE LINKS USING DOMDocument class
			$document = new DOMDocument();
			$document->loadHTML("<?xml encoding='UTF-8'>" . $content);
			// Search for all links in the content
			$links = $document->getElementsByTagName("a");
			$n = $links->length;
			$i = 0;
			
			$title_exists = $shortcode_exists = $opening_shortcode = "";
			
			while($links->item($i)) {
				$text = $links->item($i)->previousSibling->nodeValue;
				$pos = strrpos($text,"css3_tooltip");
				
				$title_exists = $links->item($i)->getAttribute("title")!=="";
				$shortcode_exists = strrpos($text,"css3_tooltip")!==false;
				$opening_shortcode = $text[strrpos($text,"css3_tooltip")-1]==="[";
				/*We need to ensure that the link isn't already inside of css3_tooltip shortcode.
				*/
				if ( $title_exists && ( !$shortcode_exists || !$opening_shortcode) ) {
					$attr_str = "";
					foreach($links->item($i)->attributes as $attr) {
						if(!in_array($attr->nodeName,array("title", "class")))
							$attr_str.=" " . $attr->nodeName . "=\"" . $attr->nodeValue . "\"" ;
					}
					$links->item($i)->parentNode->replaceChild($document->createTextNode("[css3_tooltip content='{$links->item($i)->getAttribute('title')}' position='{$default_options['position']}' tag='a' width='{$default_options['width']}' custom_css='{$default_options['custom_css']}' custom_content_css='{$default_options['custom_content_css']}' style='{$default_options['style']}' delay='{$default_options['delay']}' cursor='{$default_options['cursor']}' custom_css_class='{$default_options['custom_css_class']} {$links->item($i)->getAttribute('class')}' event='{$default_options['event']}' attr='{$attr_str}']{$links->item($i)->nodeValue}[/css3_tooltip]"),$links->item($i));
				} else {
					$i++;
				}
			}
			$content = $document->saveHTML();
		}
		return $content;
	}
	
	function css3_tooltips_text_to_tooltips($content) {
		if(get_option("css3_tooltips_text_to_tooltips") == 1) {
			$default_options = CCS3_Tooltips::css3_tooltips_default_options();
			$pattern = "/(\b{$default_options['text_to_tooltips_text']}\b)/iu";
			$tooltip = "[css3_tooltip content='{$default_options['text_to_tooltips_content']}' position='{$default_options['position']}' tag='{$default_options['tag']}' width='{$default_options['width']}' custom_css='{$default_options['custom_css']}' custom_content_css='{$default_options['custom_content_css']}' style='{$default_options['style']}' delay='{$default_options['delay']}' cursor='{$default_options['cursor']}' custom_css_class='{$default_options['custom_css_class']}' event='{$default_options['event']}']$1[/css3_tooltip]";
			$content = preg_replace($pattern, $tooltip, $content);
		}
		return $content;
	}

	function init_buttons() {
		add_filter("mce_buttons", array($this, "filter_mce_buttons"));
		add_filter("mce_external_plugins", array($this, "filter_mce_plugin"));
	}

	function filter_mce_buttons($buttons) {
		array_push($buttons, "|", "css3_tooltip_button");
		return $buttons;
	}

	function filter_mce_plugin($plugin_array) {
		$plugin_array["css3_tooltips"] = CSS3_TOOLTIPS_JS_URL . "script.js?" . filemtime(CSS3_TOOLTIPS_JS_PATH . "script.js");
		return $plugin_array;
	}

	function css3_tooltips_menu() {
		add_submenu_page(
			"options-general.php", __("CSS3 Tooltips", "css3_tooltips"), __("CSS3 Tooltips", "css3_tooltips"), "administrator", "css3_tooltips_settings", array($this, "css3_tooltips_settings_page")
		);
		add_action("admin_enqueue_scripts", array($this, "css3_tooltips_settings_scripts"));
	}

	function css3_tooltips_settings_scripts() {
		wp_enqueue_style("css3_tooltips_settings", CSS3_TOOLTIPS_CSS_URL . "settings.css");
		wp_enqueue_script("css3_tooltips_settings", CSS3_TOOLTIPS_JS_URL . "settings.js");
	}

	function css3_tooltips_settings_page() {
		require_once CSS3_TOOLTIPS_PLUGIN_PATH . "/settings.php";
	}

	function css3_tooltips_settings_save() {
		update_option("css3_tooltips_custom_css_class", sanitize_text_field($_POST["custom_css_class"]));
		update_option("css3_tooltips_custom_css", sanitize_text_field($_POST["custom_css"]));
		update_option("css3_tooltips_custom_content_css", sanitize_text_field($_POST["custom_content_css"]));
		update_option("css3_tooltips_cursor", sanitize_text_field($_POST["cursor"]));
		update_option("css3_tooltips_delay", sanitize_text_field($_POST["delay"]));
		update_option("css3_tooltips_event", sanitize_text_field($_POST["event"]));
		update_option("css3_tooltips_links_to_tooltips", sanitize_text_field($_POST["links_to_tooltips"]));		
		update_option("css3_tooltips_text_to_tooltips", sanitize_text_field($_POST["text_to_tooltips"]));
		update_option("css3_tooltips_text_to_tooltips_text", $_POST["text_to_tooltips_text"]);
		update_option("css3_tooltips_text_to_tooltips_content", $_POST["text_to_tooltips_content"]);
		update_option("css3_tooltips_position", sanitize_text_field($_POST["position"])); 
		update_option("css3_tooltips_style", sanitize_text_field($_POST["style"]));
		update_option("css3_tooltips_tag", sanitize_text_field($_POST["tag"]));
		update_option("css3_tooltips_width", sanitize_text_field($_POST["width"]));
		echo json_encode("success");
		exit();
	}
	 
	function css3_tooltips_footer() {
		global $css3_tooltips_js;
		if($css3_tooltips_js) {
			?>
			<script type="text/javascript">
			jQuery(document).ready(function(){
				jQuery("[class*='qlabs_tooltip'].event_click").on("click", function(event){
					event.preventDefault();
					event.stopPropagation();
					// DEACTIVATE PREVIOUSLY ACTIVATED TOOLTIPS
					var active_tooltips = jQuery("[class*='qlabs_tooltip'].event_click_active");
					active_tooltips.addClass("event_click"); 
					active_tooltips.removeClass("event_click_active"); 
					// ACTIVATE CLICKED TOOLTIP
					jQuery(this).addClass("event_click_active"); 
					jQuery(this).removeClass("event_click"); 
				});	 
				jQuery(document).on("click", function(event){
					// DEACTIVATE PREVIOUSLY ACTIVATED TOOLTIPS
					var active_tooltips = jQuery("[class*='qlabs_tooltip'].event_click_active");
					active_tooltips.addClass("event_click"); 
					active_tooltips.removeClass("event_click_active"); 
				});
				jQuery("[class*='qlabs_tooltip'].event_click_active a").on('click', function(event){
					 window.location = jQuery(this).attr('href');
				});
			});
			</script>
			<?php
		}
	} 
}

// RUN
new CCS3_Tooltips();
